@@ -8,7 +8,11 @@ import pandas as pd
 import numpy as np
 
 from napoleontoolbox.neural_net import roll_multi_layer_lstm
+from napoleontoolbox.neural_net import roll_multi_layer_shortcut_lstm
+
+
 from napoleontoolbox.file_saver import dropbox_file_saver
+from napoleontoolbox.neural_net import roll_multi_layer_perceptron
 from napoleontoolbox.neural_net import roll_multi_layer_shortcut_perceptron
 from napoleontoolbox.boosted_trees import roll_lightgbm
 from napoleontoolbox.features import features_type
@@ -176,9 +180,11 @@ class SimpleRunner(AbstractRunner):
 
         if self.maximum_precision:
             X = np.float64(X)
+            X_shortcut = np.float64(X_shortcut)
             y = np.float64(y)
         else :
             X = np.float32(X)
+            X_shortcut = np.float32(X_shortcut)
             y = np.float32(y)
 
 
@@ -197,7 +203,7 @@ class SimpleRunner(AbstractRunner):
                 hidden_size = int(layers[-1])
                 num_layers = int(layers[-2])
                 num_classes = y.shape[1]
-                tm = roll_multi_layer_lstm.RollMultiLayerLSTM(
+                tm = roll_multi_layer_shortcut_lstm.RollMultiLayerShortCutLSTM(
                     X=X,
                     y=y,
                     num_classes=num_classes,
@@ -252,7 +258,7 @@ class SimpleRunner(AbstractRunner):
                 tm.set_optimizer(nn.MSELoss, torch.optim.Adam, lr_type, lr=lr_start, betas=(0.9, 0.999), amsgrad=True)
                 tm = tm.set_roll_period(n, s, repass_steps=epochs)
             elif convolution == 0:
-                tm = roll_multi_layer_shortcut_perceptron.RollMultiLayerPerceptron(
+                tm = roll_multi_layer_perceptron.RollMultiLayerPerceptron(
                     X=X,
                     y=y,
                     layers=layers,
